@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Add 32nd, 64th and tuple durations to MIDI-Perl
 
-our $VERSION = '0.0602';
+our $VERSION = '0.0603';
 use strict;
 use warnings;
 
@@ -19,19 +19,18 @@ use MIDI::Simple;
         # Create a MIDI::Simple format note identifier.
         my $n = $duration . 'n';
 
-        # Compute the note duration.
-        $MIDI::Simple::Length{$n} = $duration eq $last
-            ? 4 : $MIDI::Simple::Length{ $last . 'n' } / 2;
+        # Compute the note duration, which is half of the previous.
+        $MIDI::Simple::Length{$n} = $MIDI::Simple::Length{ $last . 'n' } / 2;
 
         # Compute the dotted duration.
         $MIDI::Simple::Length{ 'd'  . $n } = $MIDI::Simple::Length{$n}
             + $MIDI::Simple::Length{$n} / 2;
 
         # Compute the double-dotted duration.
-        $MIDI::Simple::Length{ 'dd' . $n } = $MIDI::Simple::Length{'d' . $n}
+        $MIDI::Simple::Length{ 'dd' . $n } = $MIDI::Simple::Length{ 'd' . $n }
             + $MIDI::Simple::Length{$n} / 4;
 
-        # Compute triplet duration.
+        # Compute the triplet duration.
         $MIDI::Simple::Length{ 't'  . $n } = $MIDI::Simple::Length{$n} / 3 * 2;
 
         # Increment the last duration seen.
@@ -59,7 +58,7 @@ Music::Duration - Add 32nd, 64th and tuple durations to MIDI-Perl
 
 =head1 VERSION
 
-version 0.0602
+version 0.0603
 
 =head1 SYNOPSIS
 
@@ -71,11 +70,11 @@ version 0.0602
   use MIDI::Simple;
   use Music::Duration;
 
-  Music::Duration::tuple( 'ten', 'z', 5 );
+  Music::Duration::tuple( 'ten', 'z', 5 ); # 5 notes in place of an eighth note triplet
 
   my $black_page = MIDI::Simple->new_score();
   # ...
-  n( 'zten', 'n38' ) for 1 .. 5; # 5 snares in place of an eighth note triplet
+  $black_page->n( 'zten', 'n38' ) for 1 .. 5;
 
 =head1 DESCRIPTION
 
@@ -125,7 +124,7 @@ Gene Boggs <gene@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2018 by Gene Boggs.
+This software is copyright (c) 2019 by Gene Boggs.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
